.. man_aa_conf.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2011 Róbert Čerňanský



.. User documentation - aa.conf manual page



==============================
AutoArchive Configuration File
==============================

Synopsis
========

| **~/.config/aa/aa.conf**
| **/etc/aa/aa.conf**



File Format
===========

.. include:: ../general/config_file.rst
   :start-after: begin_format
   :end-before: end_format



License
=======

.. include:: ../general/general_information.rst
   :start-after: begin_license
   :end-before: end_license



See Also
========

*aa*\(1), *aa_arch_spec*\(5)



.. |usage_ref| replace:: *aa*\(1)
